/// <reference types="react" />
import AnnotationLayer from "./AnnotationLayer";
import DividedLine from "./DividedLine";
import XYFrame from "./XYFrame";
import OrdinalFrame from "./OrdinalFrame";
import MinimapXYFrame from "./MinimapXYFrame";
import MiniMap from "./MiniMap";
import Axis from "./Axis";
import Legend from "./Legend";
import Annotation from "./Annotation";
import Brush from "./Brush";
import InteractionLayer from "./InteractionLayer";
import VisualizationLayer from "./VisualizationLayer";
import NetworkFrame from "./NetworkFrame";
import { funnelize } from "./svg/lineDrawing";
import { calculateDataExtent } from "./data/dataFunctions";
import FacetController from "./FacetController";
import { ResponsiveNetworkFrame } from "./ResponsiveNetworkFrame";
import { ResponsiveMinimapXYFrame } from "./ResponsiveMinimapXYFrame";
import { ResponsiveXYFrame } from "./ResponsiveXYFrame";
import { ResponsiveOrdinalFrame } from "./ResponsiveOrdinalFrame";
import { SparkXYFrame } from "./SparkXYFrame";
import { SparkOrdinalFrame } from "./SparkOrdinalFrame";
import { SparkNetworkFrame } from "./SparkNetworkFrame";
import { Mark } from "semiotic-mark";
import { hexbinning, heatmapping } from "./svg/areaDrawing";
import { nodesEdgesFromHierarchy } from "./processing/network";
declare const _default: {
    AnnotationLayer: any;
    DividedLine: typeof DividedLine;
    XYFrame: import("react").NamedExoticComponent<import("./semiotic").XYFrameProps>;
    MinimapXYFrame: typeof MinimapXYFrame;
    MiniMap: (props: import("./MiniMap").MinimapProps) => JSX.Element;
    Brush: typeof Brush;
    Axis: typeof Axis;
    InteractionLayer: typeof InteractionLayer;
    VisualizationLayer: typeof VisualizationLayer;
    OrdinalFrame: import("react").NamedExoticComponent<import("./semiotic").OrdinalFrameProps>;
    Annotation: typeof Annotation;
    NetworkFrame: import("react").NamedExoticComponent<import("./semiotic").NetworkFrameProps>;
    ResponsiveMinimapXYFrame: {
        (props: import("./ResponsiveFrame").ResponsiveFrameProps & (import("./semiotic").XYFrameProps | import("./semiotic").OrdinalFrameProps | import("./semiotic").NetworkFrameProps)): JSX.Element;
        isResizing: number;
        displayName: string;
    };
    ResponsiveOrdinalFrame: {
        (props: import("./ResponsiveFrame").ResponsiveFrameProps & (import("./semiotic").XYFrameProps | import("./semiotic").OrdinalFrameProps | import("./semiotic").NetworkFrameProps)): JSX.Element;
        isResizing: number;
        displayName: string;
    };
    ResponsiveNetworkFrame: {
        (props: import("./ResponsiveFrame").ResponsiveFrameProps & (import("./semiotic").XYFrameProps | import("./semiotic").OrdinalFrameProps | import("./semiotic").NetworkFrameProps)): JSX.Element;
        isResizing: number;
        displayName: string;
    };
    ResponsiveXYFrame: {
        (props: import("./ResponsiveFrame").ResponsiveFrameProps & (import("./semiotic").XYFrameProps | import("./semiotic").OrdinalFrameProps | import("./semiotic").NetworkFrameProps)): JSX.Element;
        isResizing: number;
        displayName: string;
    };
    SparkOrdinalFrame: (props: {
        sparkStyle?: object;
        size?: number | number[];
    }) => JSX.Element;
    SparkNetworkFrame: (props: {
        sparkStyle?: object;
        size?: number | number[];
    }) => JSX.Element;
    SparkXYFrame: (props: {
        sparkStyle?: object;
        size?: number | number[];
    }) => JSX.Element;
    Legend: typeof Legend;
    Mark: any;
    FacetController: typeof FacetController;
    funnelize: typeof funnelize;
    calculateDataExtent: ({ lineDataAccessor, xAccessor, yAccessor, summaries, points, lines, lineType, showLinePoints, showSummaryPoints, xExtent, yExtent, invertX, invertY, summaryDataAccessor, summaryType, adjustedSize: size, margin, baseMarkProps, summaryStyleFn, summaryClassFn, summaryRenderModeFn, chartSize, filterRenderedLines, filterRenderedSummaries, filterRenderedPoints, defined, annotations }: {
        lineDataAccessor: Function[];
        summaryDataAccessor: Function[];
        summaryStyleFn: Function;
        summaryClassFn: Function;
        summaryRenderModeFn: Function;
        xAccessor: Function[];
        yAccessor: Function[];
        summaries?: import("./semiotic").RawSummary[];
        points?: import("./semiotic").RawPoint[];
        lines?: import("./semiotic").RawLine[];
        lineType: import("./semiotic").LineTypeSettings;
        showLinePoints?: string | boolean;
        showSummaryPoints?: boolean;
        xExtent?: import("./semiotic").ExtentType;
        yExtent?: import("./semiotic").ExtentType;
        invertX?: boolean;
        invertY?: boolean;
        summaryType: import("./semiotic").SummaryTypeSettings;
        adjustedSize: number[];
        chartSize: number[];
        xScaleType: Function;
        yScaleType: Function;
        baseMarkProps?: object;
        margin: import("./semiotic").MarginType;
        defined?: Function;
        annotations: object[];
        filterRenderedLines: (value: import("./semiotic").ProjectedLine, index: number, array: import("./semiotic").ProjectedLine[]) => any;
        filterRenderedSummaries: (value: import("./semiotic").ProjectedSummary, index: number, array: import("./semiotic").ProjectedSummary[]) => any;
        filterRenderedPoints: (value: import("./semiotic").ProjectedSummary | import("./semiotic").ProjectedPoint | import("./semiotic").ProjectedBin, index: number, array: (import("./semiotic").ProjectedSummary | import("./semiotic").ProjectedPoint | import("./semiotic").ProjectedBin)[]) => any;
    }) => {
        xExtent: any[];
        yExtent: any[];
        projectedLines: import("./semiotic").ProjectedLine[];
        projectedPoints: import("./semiotic").ProjectedPoint[];
        projectedSummaries: import("./semiotic").ProjectedSummary[];
        fullDataset: (import("./semiotic").ProjectedSummary | import("./semiotic").ProjectedPoint | import("./semiotic").ProjectedBin)[];
        calculatedXExtent: any[];
        calculatedYExtent: any[];
    };
    hexbinning: typeof hexbinning;
    heatmapping: typeof heatmapping;
    nodesEdgesFromHierarchy: (baseRootNode: any, idAccessor?: (d: any) => any) => {
        edges: any[];
        nodes: any[];
    };
};
export default _default;
export { AnnotationLayer, DividedLine, XYFrame, MinimapXYFrame, MiniMap, Brush, Axis, InteractionLayer, VisualizationLayer, OrdinalFrame, Annotation, NetworkFrame, ResponsiveMinimapXYFrame, ResponsiveOrdinalFrame, ResponsiveNetworkFrame, ResponsiveXYFrame, SparkOrdinalFrame, SparkNetworkFrame, SparkXYFrame, Legend, Mark, funnelize, calculateDataExtent, FacetController, hexbinning, heatmapping, nodesEdgesFromHierarchy };
